@@ -8,7 +8,7 @@ use LWP::UserAgent;
 use Safe::Isa '$_isa';
 use Storable qw( dclone nstore retrieve );
 
-our $VERSION = '1.16';
+our $VERSION = '1.17';
 
 my $instance = __PACKAGE__->__instance;
 sub __instance {
@@ -217,13 +217,15 @@ Version 1.10
 
 =head1 SYNOPSIS
 
+In your test code:
+
     # setup env vars to control behaviour, allowing them to be
     # overridden from command line.  In current case, do before
     # loading module, so will be actioned on.
 
     BEGIN {
-        $ENV{ LWP_UA_MOCK } ||= 'playback';
-        $ENV{ LWP_UA_MOCK_FILE } ||= 'lwp-mock.out';
+        $ENV{LWP_UA_MOCK}      ||= 'playback';
+        $ENV{LWP_UA_MOCK_FILE} ||= "$0-lwp-mock.out";
     }
 
     use LWP;
@@ -255,6 +257,22 @@ Version 1.10
         LWP::UserAgent::Mockable->finished;
     }
 
+To run the tests:
+
+    # Store data
+    LWP_UA_MOCK=record prove t/my-test.t
+
+    # Use stored data
+    prove t/my-test.t  # playback is default in example
+    # or
+    LWP_UA_MOCK=playback prove t/my-test.t
+
+    # Re-record stored data
+    LWP_UA_MOCK=record prove t/my-test.t
+
+    # Ignore stored data
+    LWP_UA_MOCK=passthrough prove t/my-test.t
+
 =head1 DESCRIPTION
 
 This module adds session record and playback options for LWP requests, whilst
